@@ -1,7 +1,7 @@
 package ExtUtils::MM_Any;
 
 use strict;
-our $VERSION = '6.45_02';
+our $VERSION = '6.47_01';
 
 use Carp;
 use File::Spec;
@@ -777,7 +777,7 @@ sub _hash_merge {
     if (ref $h->{$k} eq 'ARRAY') {
         push @{$h->{$k}}, ref $v ? @$v : $v;
     } elsif (ref $h->{$k} eq 'HASH') {
-        $h->{$k}{$_} = $v->{$_} foreach keys %$v;
+        $self->_hash_merge($h->{$k}, $_, $v->{$_}) foreach keys %$v;
     } else {
         $h->{$k} = $v;
     }
@@ -842,8 +842,12 @@ sub metafile_data {
             version     => 1.4
         },
     );
+
+    # The author key is required and it takes a list.
     $meta{author}   = defined $self->{AUTHOR}    ? [$self->{AUTHOR}] : [];
+
     $meta{requires} = $self->{PREREQ_PM} if defined $self->{PREREQ_PM};
+    $meta{requires}{perl} = $self->{MIN_PERL_VERSION} if $self->{MIN_PERL_VERSION};
 
     while( my($key, $val) = each %$meta_add ) {
         $meta{$key} = $val;
